Deprecated API
==============

.. tip::
    Use the right sidebar, the search widget or `Ctrl+F` to find the items you need.

.. currentmodule:: delu

.. autoclass:: EarlyStopping
    :show-inheritance:
    :members:
    :special-members:
    :exclude-members: __weakref__

.. autoclass:: Timer
    :show-inheritance:
    :members:
    :special-members:
    :exclude-members: __weakref__

.. autoclass:: ProgressTracker
    :show-inheritance:
    :members:
    :special-members:
    :exclude-members: __weakref__

.. autoclass:: Stream
    :show-inheritance:
    :members:
    :special-members:
    :exclude-members: __weakref__

.. autofunction:: collate

.. autofunction:: concat

.. autofunction:: improve_reproducibility

.. autoclass:: evaluation
    :exclude-members: __init__, __new__

.. currentmodule:: delu.utils.data

.. autoclass:: Enumerate
    :show-inheritance:
    :members:
    :special-members:
    :exclude-members: __weakref__

.. autoclass:: IndexDataset
    :show-inheritance:
    :members:
    :special-members:
    :exclude-members: __weakref__

.. currentmodule:: delu.data

.. autoclass:: Enumerate
    :show-inheritance:
    :members:
    :special-members:
    :exclude-members: __weakref__

.. autoclass:: IndexDataset
    :show-inheritance:
    :members:
    :special-members:
    :exclude-members: __weakref__

.. autoclass:: FnDataset
    :show-inheritance:
    :members:
    :special-members:
    :exclude-members: __weakref__

.. autoclass:: IndexLoader
    :show-inheritance:
    :members:
    :special-members:
    :exclude-members: __weakref__

.. autofunction:: make_index_dataloader

.. currentmodule:: delu.hardware

.. autofunction:: free_memory

.. autofunction:: get_gpus_info

.. currentmodule:: delu.nn

.. autofunction:: named_sequential

